@@ -1,8 +1,9 @@
 package Data::Verifier;
+BEGIN {
+  $Data::Verifier::VERSION = '0.41';
+}
 use Moose;
 
-our $VERSION = '0.40';
-
 use Data::Verifier::Field;
 use Data::Verifier::Filters;
 use Data::Verifier::Results;
@@ -504,14 +505,18 @@ Cory G Watson, C<< <gphat at cpan.org> >>
 
 =head1 CONTRIBUTORS
 
-J. Shirley
-
-Stevan Little
+Mike Eldridge
 
 George Hartzell
 
+Stevan Little
+
+Jason May
+
 Dennis Schön
 
+J. Shirley
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Cold Hard Code, LLC
